
# Slot: default_node_type


The node type to be used when the node type for a given node in the node file is None.

URI: [https://w3id.org/neat/ensmallenRunConfig__default_node_type](https://w3id.org/neat/ensmallenRunConfig__default_node_type)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
